@@ -2,6 +2,7 @@
 #include <gio/gio.h>
 #include <gcrypt.h>
 #include <glib/gi18n.h>
+#include "../common/file-size.h"
 #include "version.h"
 #include "../common/import-export.h"
 #include "main.h"
@@ -19,9 +20,6 @@ static gboolean  parse_options         (GApplicationCommandLine *cmdline,
 
 static gboolean  is_valid_type         (const gchar             *type);
 
-static void      handle_warning        (gboolean                *proceed,
-                                        gboolean                *show_warning);
-
 static void      g_free_cmdline_opts   (CmdlineOpts             *co);
 
 
@@ -30,7 +28,6 @@ main (gint    argc,
       gchar **argv)
 {
     g_autofree gchar *type_msg = g_strconcat ("The import/export type for the database (to be used with --import/--export, mandatory). Must be either one of: ",
-                                         ANDOTP_PLAIN_ACTION_NAME, ", ", ANDOTP_ENC_ACTION_NAME, ", ",
                                          AEGIS_PLAIN_ACTION_NAME, ", ", AEGIS_ENC_ACTION_NAME, ", ",
                                          AUTHPRO_PLAIN_ACTION_NAME, ", ", AUTHPRO_ENC_ACTION_NAME, ", ",
                                          TWOFAS_PLAIN_ACTION_NAME, ", ", TWOFAS_ENC_ACTION_NAME, ", ",
@@ -39,9 +36,7 @@ main (gint    argc,
 
     GOptionEntry entries[] =
             {
-#ifndef IS_FLATPAK
                     { "database", 'd', G_OPTION_FLAG_NONE, G_OPTION_ARG_STRING, NULL, "(optional) path to the database. Default value is taken from otpclient.cfg", NULL },
-#endif
                     { "show", 's', G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE, NULL, "Show a token for a given account.", NULL },
                     { "account", 'a', G_OPTION_FLAG_NONE, G_OPTION_ARG_STRING, NULL, "Account name (to be used with --show, mandatory)", NULL},
                     { "issuer", 'i', G_OPTION_FLAG_NONE, G_OPTION_ARG_STRING, NULL, "Issuer (to be used with --show, optional)", NULL},
@@ -67,7 +62,7 @@ main (gint    argc,
     g_application_add_main_option_entries (app, entries);
     g_application_set_option_context_parameter_string (app, ctx_text);
 
-    g_signal_connect (app, "handle-local-options", G_CALLBACK (handle_local_options), NULL);
+    g_signal_connect (app, "handle-local-options", G_CALLBACK(handle_local_options), NULL);
     g_signal_connect (app, "command-line", G_CALLBACK(command_line), NULL);
 
     int status = g_application_run (app, argc, argv);
@@ -123,26 +118,22 @@ command_line (GApplication                *application __attribute__((unused)),
         return -1;
     }
 
-    if (memlock_ret_value == MEMLOCK_TOO_LOW && get_warn_data () == TRUE) {
-        gchar *msg = g_strdup_printf (_("Your operating system's memlock limit (%d bytes) may be too low. This could cause the program to crash or, worse, use insecure memory."
-                                        "Please review the following page using this software with the current settings:"
-                                        "https://github.com/paolostivanin/OTPClient/wiki/Secure-Memory-Limitations"), db_data->max_file_size_from_memlock);
-        g_print ("%s\n", msg);
+    if (get_file_size (db_data->db_path) > (goffset)(db_data->max_file_size_from_memlock * SECMEM_SIZE_THRESHOLD_RATIO)) {
+        gchar *msg = g_strdup_printf (_(
+            "Your system's secure memory limit (memlock: %d bytes) is not enough to securely load the database into memory.\n"
+            "You need to increase your system's memlock limit by following the instructions on our "
+            "<a href=\"https://github.com/paolostivanin/OTPClient/wiki/Secure-Memory-Limitations\">secure memory wiki page</a>.\n"
+            "This requires administrator privileges and is a system-wide setting that OTPClient cannot change automatically."
+        ), db_data->max_file_size_from_memlock);
+        g_printerr ("%s\n", msg);
         g_free (msg);
-
-        gboolean proceed = FALSE;
-        gboolean show_warning = TRUE;
-        handle_warning (&proceed, &show_warning);
-        if (proceed == FALSE) {
-            g_free (db_data);
-            return -1;
-        }
-        set_warn_data (show_warning);
+        g_free (db_data);
+        return -1;
     }
 
     gchar *init_msg = init_libs (db_data->max_file_size_from_memlock);
     if (init_msg != NULL) {
-        g_application_command_line_printerr(cmdline, "Error while initializing GCrypt: %s\n", init_msg);
+        g_application_command_line_printerr (cmdline, "Error while initializing GCrypt: %s\n", init_msg);
         g_free (init_msg);
         g_free (db_data);
         return -1;
@@ -205,11 +196,10 @@ parse_options (GApplicationCommandLine *cmdline,
         if (!g_variant_dict_lookup (options, "type", "s", &cmdline_opts->import_type)) {
             g_application_command_line_print (cmdline, "Please provide an import type.\n");
             return FALSE;
-        } else {
-            if (!is_valid_type (cmdline_opts->import_type)) {
-                g_application_command_line_print (cmdline, "Please provide a valid import type (see --help).\n");
-                return FALSE;
-            }
+        }
+        if (!is_valid_type (cmdline_opts->import_type)) {
+            g_application_command_line_print (cmdline, "Please provide a valid import type (see --help).\n");
+            return FALSE;
         }
         if (!g_variant_dict_lookup (options, "file", "s", &cmdline_opts->import_file)) {
             g_application_command_line_print (cmdline, "Please provide a file to import.\n");
@@ -221,11 +211,10 @@ parse_options (GApplicationCommandLine *cmdline,
         if (!g_variant_dict_lookup (options, "type", "s", &cmdline_opts->export_type)) {
             g_application_command_line_print (cmdline, "Please provide an export type (see --help).\n");
             return FALSE;
-        } else {
-            if (!is_valid_type (cmdline_opts->export_type)) {
-                g_application_command_line_print (cmdline, "Please provide a valid export type.\n");
-                return FALSE;
-            }
+        }
+        if (!is_valid_type (cmdline_opts->export_type)) {
+            g_application_command_line_print (cmdline, "Please provide a valid export type.\n");
+            return FALSE;
         }
 #ifndef IS_FLATPAK
         g_variant_dict_lookup (options, "output-dir", "s", &cmdline_opts->export_dir);
@@ -238,8 +227,7 @@ parse_options (GApplicationCommandLine *cmdline,
 static gboolean
 is_valid_type (const gchar *type)
 {
-    const gchar *supported_types[] = {ANDOTP_PLAIN_ACTION_NAME, ANDOTP_ENC_ACTION_NAME,
-                                      AEGIS_PLAIN_ACTION_NAME, AEGIS_ENC_ACTION_NAME,
+    const gchar *supported_types[] = {AEGIS_PLAIN_ACTION_NAME, AEGIS_ENC_ACTION_NAME,
                                       TWOFAS_PLAIN_ACTION_NAME, TWOFAS_ENC_ACTION_NAME,
                                       AUTHPRO_PLAIN_ACTION_NAME, AUTHPRO_ENC_ACTION_NAME,
                                       FREEOTPPLUS_PLAIN_ACTION_NAME};
@@ -257,54 +245,6 @@ is_valid_type (const gchar *type)
 }
 
 
-static void
-handle_warning (gboolean *proceed,
-                gboolean *show_warning)
-{
-    GError *error = NULL;
-    gchar *input = NULL;
-    gsize len;
-
-    GIOChannel *in_channel = g_io_channel_unix_new (fileno(stdin));
-
-    g_print ("\nDo you want to proceed with the current settings (Y/N)? ");
-    GIOStatus ret = g_io_channel_read_line (in_channel, &input, &len, NULL, &error);
-    if (ret == G_IO_STATUS_ERROR) {
-        g_printerr ("Error reading input: %s\n", error ? error->message : "unknown error");
-        g_clear_error (&error);
-        g_free (input);
-        return;
-    }
-    if (g_ascii_strncasecmp (input, "Y", 1) == 0) {
-        g_print ("\nProceeding with current settings...\n");
-        *proceed = TRUE;
-    } else {
-        g_print ("\nSettings not accepted.\n");
-        g_free (input);
-        return;
-    }
-    g_free (input);
-
-    g_print ("\nDo you want to disable this warning (Y/N)? ");
-    ret = g_io_channel_read_line (in_channel, &input, &len, NULL, &error);
-    if (ret == G_IO_STATUS_ERROR) {
-        g_printerr ("Error reading input: %s\n", error ? error->message : "unknown error");
-        g_clear_error (&error);
-        g_free (input);
-        return;
-    }
-    if (g_ascii_strncasecmp (input, "Y", 1) == 0) {
-        g_print("\nWarning disabled.\n");
-        *show_warning = FALSE;
-    } else {
-        g_print ("\nWarning remains enabled.\n");
-    }
-    g_free(input);
-
-    g_io_channel_unref(in_channel);
-}
-
-
 static void
 g_free_cmdline_opts (CmdlineOpts *co)
 {
