@@ -177,40 +177,17 @@ get_authpro_derived_key (const gchar *password,
 }
 
 
-guchar *
-get_andotp_derived_key (const gchar  *password,
-                        const guchar *salt,
-                        guint32       iterations)
-{
-    guchar *derived_key = gcry_malloc_secure (32);
-    gpg_error_t g_err = gcry_kdf_derive (password, (gsize)g_utf8_strlen (password, -1), GCRY_KDF_PBKDF2, GCRY_MD_SHA1,
-                                         salt, ANDOTP_IV_SALT, iterations, 32, derived_key);
-    if (g_err != GPG_ERR_NO_ERROR) {
-        g_printerr ("Failed to derive key: %s/%s\n", gcry_strsource (g_err), gcry_strerror (g_err));
-        gcry_free (derived_key);
-        return NULL;
-    }
-
-    return derived_key;
-}
-
-
 gchar *
 get_data_from_encrypted_backup (const gchar       *path,
                                 const gchar       *password,
                                 gint32             max_file_size,
                                 gint32             provider,
-                                guint32            andotp_be_iterations,
                                 GFile             *in_file,
                                 GFileInputStream  *in_stream,
                                 GError           **err)
 {
     gint32 salt_size = 0, iv_size = 0, tag_size = 0;
     switch (provider) {
-        case ANDOTP:
-            salt_size = iv_size = ANDOTP_IV_SALT;
-            tag_size = ANDOTP_TAG;
-            break;
         case AUTHPRO:
             salt_size = tag_size = AUTHPRO_SALT_TAG;
             iv_size = AUTHPRO_IV;
@@ -247,10 +224,6 @@ get_data_from_encrypted_backup (const gchar       *path,
     gsize enc_buf_size;
     gint32 offset = 0;
     switch (provider) {
-        case ANDOTP:
-            // 4 is the size of iterations (int32)
-            offset = 4;
-            break;
         case AUTHPRO:
             // 16 is the size of the header
             offset = 16;
@@ -287,9 +260,6 @@ get_data_from_encrypted_backup (const gchar       *path,
 
     guchar *derived_key = NULL;
     switch (provider) {
-        case ANDOTP:
-            derived_key = get_andotp_derived_key (password, salt, andotp_be_iterations);
-            break;
         case AUTHPRO:
             derived_key = get_authpro_derived_key (password, salt);
             break;
@@ -477,42 +447,16 @@ get_kf_ptr (void)
 
 
 gboolean
-get_warn_data (void)
+is_secmem_available (gsize    required_size,
+                     GError **err)
 {
-    GKeyFile *kf = get_kf_ptr ();
-    gboolean show_warning = TRUE;
-    GError *err = NULL;
-    if (kf != NULL) {
-        show_warning = g_key_file_get_boolean (kf, "config", "show_memlock_warning", &err);
-        if (err != NULL && (err->code == G_KEY_FILE_ERROR_KEY_NOT_FOUND || err->code == G_KEY_FILE_ERROR_INVALID_VALUE)) {
-            // value is not present, so we want to show the warning
-            show_warning = TRUE;
-        }
-        g_key_file_free (kf);
-    }
-
-    return show_warning;
-}
-
-
-void
-set_warn_data (gboolean show_warning)
-{
-    GKeyFile *kf = get_kf_ptr ();
-    GError *err = NULL;
-    if (kf != NULL) {
-        g_key_file_set_boolean (kf, "config", "show_memlock_warning", show_warning);
-        gchar *cfg_file_path;
-#ifndef IS_FLATPAK
-        cfg_file_path = g_build_filename (g_get_user_config_dir (), "otpclient.cfg", NULL);
-#else
-        cfg_file_path = g_build_filename (g_get_user_data_dir (), "otpclient.cfg", NULL);
-#endif
-        if (!g_key_file_save_to_file (kf, cfg_file_path, &err)) {
-            g_printerr ("%s\n", err->message);
-            g_clear_error (&err);
-        }
-        g_free (cfg_file_path);
-        g_key_file_free (kf);
+    void *test = gcry_malloc_secure (required_size);
+    if (test == NULL) {
+        g_set_error(err, secmem_alloc_error_gquark (), NO_SECMEM_AVAIL_ERRCODE,
+                   "Not enough secure memory available (%zu bytes requested).",
+                   required_size);
+        return FALSE;
     }
+    gcry_free (test);
+    return TRUE;
 }
\ No newline at end of file
