@@ -48,15 +48,16 @@ parse_data_and_update_db (AppData       *app_data,
     GError *err = NULL;
     gchar *pwd = NULL;
 
-    if (g_strcmp0 (action_name, ANDOTP_ENC_ACTION_NAME) == 0 || g_strcmp0 (action_name, AEGIS_ENC_ACTION_NAME) == 0 ||
-        g_strcmp0 (action_name, AUTHPRO_ENC_ACTION_NAME) == 0 || g_strcmp0 (action_name, TWOFAS_ENC_ACTION_NAME) == 0) {
+    if (g_strcmp0 (action_name, AEGIS_ENC_ACTION_NAME) == 0 ||
+        g_strcmp0 (action_name, AUTHPRO_ENC_ACTION_NAME) == 0 ||
+        g_strcmp0 (action_name, TWOFAS_ENC_ACTION_NAME) == 0) {
         pwd = prompt_for_password (app_data, NULL, action_name, FALSE);
         if (pwd == NULL) {
             return FALSE;
         }
     }
 
-    GSList *content = get_data_from_provider (action_name, filename, pwd, app_data->db_data->max_file_size_from_memlock, &err);
+    GSList *content = get_data_from_provider (action_name, filename, pwd, app_data->db_data->max_file_size_from_memlock, json_dumpb (app_data->db_data->in_memory_json_data, NULL, 0, 0), &err);
     if (content == NULL) {
         const gchar *msg = "An error occurred while importing, so nothing has been added to the database.";
         gchar *msg_with_err = NULL;
